By default, captions are displayed above the table. You can change this
with caption_pos().
Usage
caption(ht)
caption(ht) <- value
set_caption(ht, value)
Value
property() returns the property value(s).
set_property() and map_property() return the modified huxtable.
Arguments
ht
A huxtable.
value
A string. Set to NA to reset to the default, which is NA_character_.
Details
Captions are not escaped. See the example for a workaround.
Table captions set via the knitr tab.cap or Quarto tbl-cap and
tbl-subcap chunk options override captions set by this mechanism. A warning
is issued if both are set.
See Also
Other caption properties:
caption_pos(),
caption_width()