View source: R/properties-table.R
| breakable | R Documentation |
breakable() controls whether a table may break between rows across pages.
Individual rows are kept together. It affects paged HTML, LaTeX, RTF, Typst,
and Word output; other output formats ignore it.
breakable(ht)
breakable(ht) <- value
set_breakable(ht, value)
ht |
A huxtable. |
value |
Logical. Set to |
In LaTeX, breakable tables use the longtable environment and therefore
require a one-column layout. They cannot have a fixed height() or use a
wrapping position().
property() returns the property value(s).
set_property() and map_property() return the modified huxtable.
set_breakable(jams, TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.