LaTeX table labels typically start with "tab:".
Within knitr, huxtable labels default to the knitr chunk label. If a chunk
prints more than one huxtable, later labels have "-2", "-3" and so on
appended to make them unique. To turn off this behaviour, set
options(huxtable.autolabel = FALSE).
If you use bookdown, and set a label on your
table, the table caption() will automatically be prefixed with (#label).
You can then refer to the table using @ref(label). label needs to start
with "tab:"; if it doesn't, the "tab:" prefix will be added
automatically. To turn off this behaviour, set
options(huxtable.bookdown = FALSE).
Quarto table labels override labels set by this mechanism. A warning is
issued if both are set.