Learn R Programming

huxtable (version 4.3.0)

position: Table position

Description

Functions to get or set the table-level table position property of a huxtable.

Usage

position(ht)
position(ht) <- value
set_position(ht, value)

Arguments

ht

A huxtable.

value

A length-one character vector which may be "left", "center" or "right". Set to NA to reset to the default, which is "center".

Value

For position, the position property. For set_position, the modified huxtable.

Details

If your tables are too far to the right under LaTeX, try setting their width() explicitly.

Examples

Run this code
# NOT RUN {
position(jams) <-  "right"
position(jams)

# }

Run the code above in your browser using DataLab