powered by
Functions to get or set the table-level table position property of a huxtable.
position(ht) position(ht) <- value set_position(ht, value)
A huxtable.
A length-one character vector which may be "left", "center" or "right". Set to NA to reset to the default, which is "center".
NA
"center"
For position, the position property. For set_position, the modified huxtable.
position
set_position
If your tables are too far to the right under LaTeX, try setting their width() explicitly.
width()
# NOT RUN { position(jams) <- "right" position(jams) # }
Run the code above in your browser using DataLab